@@ -18,13 +18,16 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.             *
  ***************************************************************************/
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include "htmlexporter.h"
 #include "bnpview.h"
 #include "basketlistview.h"
 #include "basket.h"
 #include "note.h"
 #include "tools.h"
-#include "config.h"
 #include "tag.h"
 
 #include <tdeapplication.h>
@@ -154,18 +157,18 @@ void HTMLExporter::exportBasket(Basket *basket, bool isSubBasket)
 	imagesFolderName  = (isSubBasket ? "../" : filesFolderName) + i18n("HTML export folder (images)",  "images")  + "/"; // eg.: "foo.html_files/images/"  or "../images/"
 
 	std::cout << "Exporting ================================================" << std::endl;
-	std::cout << "  filePath:" << filePath << std::endl;
-	std::cout << "  basketFilePath:" << basketFilePath << std::endl;
-	std::cout << "  filesFolderPath:" << filesFolderPath << std::endl;
-	std::cout << "  filesFolderName:" << filesFolderName << std::endl;
-	std::cout << "  iconsFolderPath:" << iconsFolderPath << std::endl;
-	std::cout << "  iconsFolderName:" << iconsFolderName << std::endl;
-	std::cout << "  imagesFolderPath:" << imagesFolderPath << std::endl;
-	std::cout << "  imagesFolderName:" << imagesFolderName << std::endl;
-	std::cout << "  dataFolderPath:" << dataFolderPath << std::endl;
-	std::cout << "  dataFolderName:" << dataFolderName << std::endl;
-	std::cout << "  basketsFolderPath:" << basketsFolderPath << std::endl;
-	std::cout << "  basketsFolderName:" << basketsFolderName << std::endl;
+	std::cout << "  filePath:" << filePath.local8Bit() << std::endl;
+	std::cout << "  basketFilePath:" << basketFilePath.local8Bit() << std::endl;
+	std::cout << "  filesFolderPath:" << filesFolderPath.local8Bit() << std::endl;
+	std::cout << "  filesFolderName:" << filesFolderName.local8Bit() << std::endl;
+	std::cout << "  iconsFolderPath:" << iconsFolderPath.local8Bit() << std::endl;
+	std::cout << "  iconsFolderName:" << iconsFolderName.local8Bit() << std::endl;
+	std::cout << "  imagesFolderPath:" << imagesFolderPath.local8Bit() << std::endl;
+	std::cout << "  imagesFolderName:" << imagesFolderName.local8Bit() << std::endl;
+	std::cout << "  dataFolderPath:" << dataFolderPath.local8Bit() << std::endl;
+	std::cout << "  dataFolderName:" << dataFolderName.local8Bit() << std::endl;
+	std::cout << "  basketsFolderPath:" << basketsFolderPath.local8Bit() << std::endl;
+	std::cout << "  basketsFolderName:" << basketsFolderName.local8Bit() << std::endl;
 
 	// Create the data folder for this basket:
 	TQDir dir;
