@@ -13,11 +13,13 @@
  * exact licensing terms.
  */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include "kiconcanvas.h"
 #include "kicondialog.h"
 
-#include <config.h>
-
 #include <kiconviewsearchline.h>
 
 #include <tdeapplication.h>
@@ -41,8 +43,7 @@
 #include <algorithm>
 
 #ifdef HAVE_LIBART
-#include <svgicons/ksvgiconengine.h>
-#include <svgicons/ksvgiconpainter.h>
+#include <ksvgiconengine.h>
 #endif
 
 class TDEIconCanvasItem : public TQIconViewItem
@@ -80,7 +81,7 @@ class TDEIconCanvas::TDEIconCanvasPrivate
     TQString mSetCurrent;
     int mSize;
 #ifdef HAVE_LIBART
-    KSvgIconEngine mSvgEngine;
+    KSVGIconEngine mSvgEngine;
 #endif
     bool mStrictIconSize;
 };
@@ -127,7 +128,7 @@ void TDEIconCanvas::loadIcon(const TQString &name)
 #ifdef HAVE_LIBART
    else
        if (d->mSvgEngine.load(maxSize, maxSize, path))
-        img = *d->mSvgEngine.painter()->image();
+        img = *d->mSvgEngine.image();
 #endif
 
    if (img.isNull())
